# ArviZ Community Code of Conduct

ArviZ adopts the NumFOCUS Code of Conduct directly. In other words, we
expect our community to treat others with kindness and understanding.


# THE SHORT VERSION  
Be kind to others. Do not insult or put down others.
Behave professionally. Remember that harassment and sexist, racist,
or exclusionary jokes are not appropriate.

All communication should be appropriate for a professional audience
including people of many different backgrounds. Sexual language and
imagery are not appropriate.

ArviZ is dedicated to providing a harassment-free community for everyone,
regardless of gender, sexual orientation, gender identity, and
expression, disability, physical appearance, body size, race,
or religion. We do not tolerate harassment of community members
in any form.

Thank you for helping make this a welcoming, friendly community for all.


# How to Submit a Report
If you feel that there has been a Code of Conduct violation an anonymous
reporting form is available.
**If you feel your safety is in jeopardy or the situation is an
emergency, we urge you to contact local law enforcement before making
a report. (In the U.S., dial 911.)**

We are committed to promptly addressing any reported issues.
If you have experienced or witnessed behavior that violates this 
Code of Conduct, please complete the form below to
make a report.

**REPORTING FORM:** https://numfocus.typeform.com/to/ynjGdT

Reports are sent to the NumFOCUS Code of Conduct Enforcement Team
(see below).

You can view the Privacy Policy and Terms of Service for TypeForm here.
The NumFOCUS Privacy Policy is here:
https://www.numfocus.org/privacy-policy


# Full Code of Conduct
The full text of the NumFOCUS/ArviZ Code of Conduct can be found on
NumFOCUS's website  
https://numfocus.org/code-of-conduct
